@@ -185,12 +185,16 @@ def hhclub_upload(siteinfo,file1,record_path,qbinfo,basic,hashlist):
         tags.append(4)
     if 'WEB' in file1.type:
         tags.append(4)
+        logger.info('已选择WEB')
     if 'hhclub' in file1.pathinfo.exclusive :
         tags.append(1)
+        logger.info('已选择禁转')
     if '国' in file1.language or '中' in file1.language:
         tags.append(5)
+        logger.info('已选择国语')
     if not file1.sublan=='' and ('简' in file1.sublan or '繁' in file1.sublan or '中' in file1.sublan):
         tags.append(6)
+        logger.info('已选择中字')
 
     
     tags=list(set(tags))
